#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_HERMITE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_HERMITE_HPP_INCLUDED

#include <nt2/polynomials/include/functions/scalar/hermite.hpp>

#endif
